﻿--------------------------------------------------------------------------------
--  iTip
--------------------------------------------------------------------------------
local ITIP_DEBUG = false;
local ITIP_VERSION = 1.2;

if not ITIP_CONFIG then
	ITIP_CONFIG = {
		["active"] = true,
	};
end

--------------------------------------------------------------------------------

local localization,lang,labels;

localization = {
	["zhCN"] = {"物品等级","堆叠大小","物品编号"}, --Chinese (simplified)
	["zhTW"] = {"物品等級","堆疊大小","物品編號"}, --Chinese (traditional)
	["enUS"] = {"Item Level","Stack Size","Item ID"}, --English (United States and Great Britain)
	["frFR"] = {"Niveau de l'élément","Taille de la pile","Numéro d'identification"}, --French
	["deDE"] = {"Positionsebene","Stack-Größe","Identifikationsnummer"}, --German
	["koKR"] = {"항목 레벨","스택의 크기","식별 번호"}, --Korean
	["ruRU"] = {"на уровне элементов","размер стека","идентификационный номер"}, --Russian (UI AddOn)
	["esES"] = {"Nivel de Articulo","Tamaño de Pila","Número por Identificación"}, --Spanish (Spain)
	["esMX"] = {"Nivel de Articulo","Tamaño de Pila","Número por Identificación"}, --Spanish (Mexico)
}

lang = GetLocale();
labels = localization[lang];

if (labels == null) or (#labels < 3) then
	labels = localization["enUS"];
end

--------------------------------------------------------------------------------

function iTip_Hook( tooltip )
	--if ITIP_DEBUG then print(MSG_PRE.."Hook function called for "..tooltip:GetName().." "..tooltip:GetItem()); end
	
	if ITIP_CONFIG.active then
		local prefix, itemID;

		-- get full item info
		local itemName, itemLink = tooltip:GetItem();
		-- make sure this is actually an item
		if itemLink then
			prefix, itemID = strsplit(':', itemLink);
			local sName, sLink, iQuality, iLevel, iMinLevel, sType, sSubType, iStackSize, sEquipLoc = GetItemInfo(itemID);
		
			-- check result
			if sType then
				------------------------------------------------------------
				-- INSERT TOOLTIP LINES
				------------------------------------------------------------
				if (strlen(sEquipLoc) == 0) then tooltip:AddLine("\n"..sType.." ("..sSubType..")"); end
				if (iStackSize > 1) then tooltip:AddLine(labels[2]..":  "..iStackSize, 1,1,1); end
				if (strlen(sEquipLoc) == 0) then tooltip:AddLine(labels[1]..":  "..iLevel, 1,1,1); end
				tooltip:AddLine(labels[3]..":  "..itemID, 1,1,1);
				
			elseif ITIP_DEBUG then
				print(MSG_PRE.."Error: GetItemInfo failed!");
			end
		end
	end
end

function iTip_Toggle( input, editbox )
	if editbox then
		local msg;
		
		if ITIP_CONFIG.active then
			ITIP_CONFIG.active = false;
			msg = "Addon disabled.";
		else
			ITIP_CONFIG.active = true;
			msg = "Addon enabled.";
		end
		
		DEFAULT_CHAT_FRAME:AddMessage("|cFF33CCFF[iTip]|cFFFFFFFF  "..msg);
	end
end

--------------------------------------------------------------------------------

-- register slash command
SLASH_iTip1 = "/itip";
SlashCmdList["iTip"] = iTip_Toggle;

-- register hook
GameTooltip:HookScript("OnTooltipSetItem", iTip_Hook);

-- loading output
DEFAULT_CHAT_FRAME:AddMessage(
	"|cFF33CCFF".."iTip v"..tostring(ITIP_VERSION).." loaded.  By CHiLLZ  (aka: Somnifer of Icecrown)\n"..
	"|cFFFFFFFF".."Type /itip to switch tooltip enhancement on/off."
);
